@@ -639,6 +639,7 @@ IPPAPI(IppStatus, ippsHKDF,(const Ipp8u* ikm, int ikmLen,
                             const Ipp8u* info, int infoLen,
                             const IppsHashMethod* pMethod))
 
+
 IPPAPI(IppStatus, ippsHKDF_extract,(const Ipp8u* ikm, int ikm_len,
                                     Ipp8u* prk, const Ipp8u* salt, int salt_len,
                                     const IppsHashMethod* pMethod))
@@ -649,6 +650,14 @@ IPPAPI(IppStatus, ippsHKDF_expand,(const Ipp8u* prk, int prk_len,
                                    const IppsHashMethod* pMethod))
 
 
+/* Password-based cryptography key derivation function PKCS5-PBKDF2 */
+IPPAPI(IppStatus, ippsPBKDF2_PKCS5v2,(const Ipp8u* pass, int passLen,
+                                     Ipp8u* odk,  int odkLen,
+                                     const Ipp8u* salt, int saltLen,
+                                     int c,
+                                     const IppsHashMethod* pMethod))
+
+
 /*
 // =========================================================
 // Big Number Integer Arithmetic
@@ -705,7 +714,6 @@ A more secure alternative is available: ippsPRNGenRDRAND and ippsTRNGenRDSEED."
 
 IPPAPI(IppStatus, ippsPRNGGetSize,(int* pSize))
 IPPAPI(IppStatus, ippsPRNGInit,   (int seedBits, IppsPRNGState* pCtx))
-
 IPPAPI(IppStatus, ippsPRNGSetModulus,(const IppsBigNumState* pMod, IppsPRNGState* pCtx))
 IPPAPI(IppStatus, ippsPRNGSetH0,     (const IppsBigNumState* pH0,  IppsPRNGState* pCtx))
 IPPAPI(IppStatus, ippsPRNGSetAugment,(const IppsBigNumState* pAug, IppsPRNGState* pCtx))
@@ -721,6 +729,52 @@ IPPAPI(IppStatus, ippsPRNGenRDRAND_BN,(IppsBigNumState* pRand, int nBits, void*
 IPPAPI(IppStatus, ippsTRNGenRDSEED,   (Ipp32u* pRand, int nBits, void* pCtx))
 IPPAPI(IppStatus, ippsTRNGenRDSEED_BN,(IppsBigNumState* pRand, int nBits, void* pCtx))
 
+IPPAPI(IppStatus, ippsHashDRBG_EntropyInputCtxGetSize, (int* pEntrInputSize,
+                                                        const int entrInputBufBitsLen,
+                                                        const IppsHashMethod* pHashMethod))
+IPPAPI(IppStatus, ippsHashDRBG_EntropyInputCtxInit, (IppsHashDRBG_EntropyInputCtx* pEntrInputCtx,
+                                                     const int entrInputBitsLen,
+                                                     IppEntropyInputSupplier getEntropyInput))
+IPPAPI(IppStatus, ippsHashDRBG_GetSize, (int* pSize, const IppsHashMethod* pHashMethod))
+IPPAPI(IppStatus, ippsHashDRBG_Init, (const IppsHashMethod* pHashMethod,
+                                      IppsHashDRBGState* pDrbgCtx))
+IPPAPI(IppStatus, ippsHashDRBG_Instantiate, (const int requestedInstSecurityStrength,
+                                             const int predictionResistanceFlag,
+                                             const Ipp8u* persStr,
+                                             const int persStrBitsLen,
+                                             IppsHashDRBG_EntropyInputCtx* pEntrInputCtx,
+                                             IppsHashDRBGState* pDrbgCtx))
+IPPAPI(IppStatus, ippsHashDRBG_Uninstantiate, (IppsHashDRBGState* pDrbgCtx))
+IPPAPI(IppStatus, ippsHashDRBG_Reseed, (const int predictionResistanceRequest,
+                                        const Ipp8u* addlInput,
+                                        const int addlInputBitsLen,
+                                        IppsHashDRBG_EntropyInputCtx* pEntrInputCtx,
+                                        IppsHashDRBGState* pDrbgCtx))
+IPPAPI(IppStatus, ippsHashDRBG_Gen, (Ipp32u* pRand,
+                                     int nBits,
+                                     const int requestedSecurityStrength,
+                                     const int predictionResistanceRequest,
+                                     const Ipp8u* addlInput,
+                                     const int addlInputBitsLen,
+                                     IppsHashDRBG_EntropyInputCtx* pEntrInputCtx,
+                                     IppsHashDRBGState* pDrbgCtx))
+IPPAPI(IppStatus, ippsHashDRBG_GenBN, (IppsBigNumState* pRand,
+                                       int nBits,
+                                       const int requestedSecurityStrength,
+                                       const int predictionResistanceRequest,
+                                       const Ipp8u* addlInput,
+                                       const int addlInputBitsLen,
+                                       IppsHashDRBG_EntropyInputCtx* pEntrInputCtx,
+                                       IppsHashDRBGState* pDrbgCtx))
+IPPAPI(IppStatus, ippsHashDRBG_InstantiateTest, (IppsHashDRBG_EntropyInputCtx* pEntrInputCtxTempBuf,
+                                                 IppsHashDRBGState* pDrbgCtxTempBuf))
+IPPAPI(IppStatus, ippsHashDRBG_ReseedTest, (IppsHashDRBG_EntropyInputCtx* pEntrInputCtxTempBuf,
+                                            IppsHashDRBGState* pDrbgCtxTempBuf))
+IPPAPI(IppStatus, ippsHashDRBG_GenTest, (Ipp32u* pRand,
+                                         int nBits,
+                                         IppsHashDRBG_EntropyInputCtx* pEntrInputCtxTempBuf,
+                                         IppsHashDRBGState* pDrbgCtxTempBuf))
+
 /* Probable Prime Number Generation */
 IPPAPI(IppStatus, ippsPrimeGetSize,(int nMaxBits, int* pSize))
 IPPAPI(IppStatus, ippsPrimeInit,   (int nMaxBits, IppsPrimeState* pCtx))
@@ -752,6 +806,9 @@ IPPAPI(IppStatus, ippsRSA_InitPublicKey,(int rsaModulusBitSize, int publicExpBit
 IPPAPI(IppStatus, ippsRSA_SetPublicKey,(const IppsBigNumState* pModulus,
                                         const IppsBigNumState* pPublicExp,
                                         IppsRSAPublicKeyState* pKey))
+IPPAPI(IppStatus, ippsRSA_SetPublicKeyPart,(IppRSAKeyTag keyTag,
+                                            const IppsBigNumState* pValue,
+                                            IppsRSAPublicKeyState* pKey))
 IPPAPI(IppStatus, ippsRSA_GetPublicKey,(IppsBigNumState* pModulus,
                                         IppsBigNumState* pPublicExp,
                                   const IppsRSAPublicKeyState* pKey))
@@ -762,6 +819,9 @@ IPPAPI(IppStatus, ippsRSA_InitPrivateKeyType1,(int rsaModulusBitSize, int privat
 IPPAPI(IppStatus, ippsRSA_SetPrivateKeyType1,(const IppsBigNumState* pModulus,
                                               const IppsBigNumState* pPrivateExp,
                                               IppsRSAPrivateKeyState* pKey))
+IPPAPI(IppStatus, ippsRSA_SetPrivateKeyType1Part,(IppRSAKeyTag keyTag,
+                                                  const IppsBigNumState* pValue,
+                                                  IppsRSAPrivateKeyState* pKey))
 IPPAPI(IppStatus, ippsRSA_GetPrivateKeyType1,(IppsBigNumState* pModulus,
                                               IppsBigNumState* pPrivateExp,
                                         const IppsRSAPrivateKeyState* pKey))
@@ -775,6 +835,9 @@ IPPAPI(IppStatus, ippsRSA_SetPrivateKeyType2,(const IppsBigNumState* pFactorP,
                                               const IppsBigNumState* pCrtExpQ,
                                               const IppsBigNumState* pInverseQ,
                                               IppsRSAPrivateKeyState* pKey))
+IPPAPI(IppStatus, ippsRSA_SetPrivateKeyType2Part,(IppRSAKeyTag keyTag,
+                                                  const IppsBigNumState* pValue,
+                                                  IppsRSAPrivateKeyState* pKey))
 IPPAPI(IppStatus, ippsRSA_GetPrivateKeyType2,(IppsBigNumState* pFactorP,
                                               IppsBigNumState* pFactorQ,
                                               IppsBigNumState* pCrtExpP,
@@ -1346,6 +1409,33 @@ IPPAPI(IppStatus, ippsLMSVerify, (const Ipp8u* pMsg, const Ipp32s msgLen,
                                   int*  pIsSignValid,
                                   const IppsLMSPublicKeyState* pKey,
                                   Ipp8u* pBuffer))
+
+IPPAPI(IppStatus, ippsLMSKeyGenBufferGetSize, (Ipp32s* pSize, const IppsLMSAlgoType lmsType))
+IPPAPI(IppStatus, ippsLMSSignBufferGetSize, (Ipp32s* pSize, Ipp32s maxMessageLength, const IppsLMSAlgoType lmsType))
+
+IPPAPI(IppStatus, ippsLMSPrivateKeyStateGetSize, (Ipp32s* pSize,
+                                                  const IppsLMSAlgoType lmsType,
+                                                  Ipp32s extraBufSize))
+
+IPPAPI(IppStatus, ippsLMSInitKeyPair, (const IppsLMSAlgoType lmsType,
+                                       Ipp32s extraBufSize,
+                                       IppsLMSPrivateKeyState* pPrvKey,
+                                       IppsLMSPublicKeyState* pPubKey))
+IPPAPI(IppStatus, ippsLMSInitSignature, (const IppsLMSAlgoType lmsType, IppsLMSSignatureState* pSign))
+
+IPPAPI(IppStatus, ippsLMSKeyGen, (IppsLMSPrivateKeyState* pPrvKey,
+                                  IppsLMSPublicKeyState* pPubKey,
+                                  IppBitSupplier rndFunc,
+                                  void* pRndParam,
+                                  Ipp8u* pBuffer))
+IPPAPI(IppStatus, ippsLMSSign, (const Ipp8u* pMsg,
+                                const Ipp32s msgLen,
+                                IppsLMSPrivateKeyState* pPrvKey,
+                                IppsLMSSignatureState* pSign,
+                                IppBitSupplier rndFunc,
+                                void* pRndParam,
+                                Ipp8u* pBuffer))
+
 #endif // IPPCP_PREVIEW_LMS
 
 #ifdef IPPCP_PREVIEW_ML_KEM
@@ -1370,6 +1460,47 @@ IPPAPI(IppStatus, ippsMLKEM_Decaps, (const Ipp8u* pDecKey, const Ipp8u* pCipherT
 
 #endif // IPPCP_PREVIEW_ML_KEM
 
+#ifdef IPPCP_PREVIEW_ML_DSA
+/* Module-Lattice-Based Digital Signature Algorithm */
+
+IPPAPI(IppStatus, ippsMLDSA_GetSize, (int* pSize))
+IPPAPI(IppStatus, ippsMLDSA_GetInfo, (IppsMLDSAInfo* pInfo, IppsMLDSAParamSet schemeType))
+
+IPPAPI(IppStatus, ippsMLDSA_Init, (IppsMLDSAState* pMLDSAState, Ipp32s maxMessageLength, IppsMLDSAParamSet schemeType))
+
+IPPAPI(IppStatus, ippsMLDSA_KeyGenBufferGetSize, (int* pSize, const IppsMLDSAState* pMLDSAState))
+IPPAPI(IppStatus, ippsMLDSA_SignBufferGetSize, (int* pSize, const IppsMLDSAState* pMLDSAState))
+IPPAPI(IppStatus, ippsMLDSA_VerifyBufferGetSize, (int* pSize, const IppsMLDSAState* pMLDSAState))
+
+IPPAPI(IppStatus, ippsMLDSA_KeyGen, (Ipp8u* pPubKey,
+                                     Ipp8u* pPrvKey,
+                                     IppsMLDSAState* pMLDSAState,
+                                     Ipp8u* pScratchBuffer,
+                                     IppBitSupplier rndFunc,
+                                     void* pRndParam))
+
+IPPAPI(IppStatus, ippsMLDSA_Sign, (const Ipp8u* pMsg,
+                                   const Ipp32s msgLen,
+                                   const Ipp8u* pCtx,
+                                   const Ipp32s ctxLen,
+                                   const Ipp8u* pPrvKey,
+                                   Ipp8u* pSign,
+                                   IppsMLDSAState* pMLDSAState,
+                                   Ipp8u* pScratchBuffer,
+                                   IppBitSupplier rndFunc,
+                                   void* pRndParam))
+
+IPPAPI(IppStatus, ippsMLDSA_Verify, (const Ipp8u* pMsg,
+                                     const Ipp32s msgLen,
+                                     const Ipp8u* pCtx,
+                                     const Ipp32s ctxLen,
+                                     const Ipp8u* pPubKey,
+                                     const Ipp8u* pSign,
+                                     int* pIsSignValid,
+                                     IppsMLDSAState* pMLDSAState,
+                                     Ipp8u* pScratchBuffer))
+#endif // IPPCP_PREVIEW_ML_DSA
+
 #if defined(_MSC_VER) && !defined(__INTEL_COMPILER) && !defined(__INTEL_LLVM_COMPILER)
 #pragma warning(pop)
 #endif
