@@ -429,6 +429,7 @@ typedef signed int IppStatus;
 #define ippStsNoOperation                    1 /* No operation has been executed. */
 #define ippStsDivByZero                      2 /* Zero value(s) for the divisor in the Div function. */
 #define ippStsWaterfall                     43 /* Cannot load required library, waterfall is used. */
+#define ippStsSizeWrn                       48 /* The size does not allow to perform full operation. */
 #define ippStsFeaturesCombination           51 /* Wrong combination of features. */
 
 #ifdef __cplusplus
@@ -437,6 +438,8 @@ typedef signed int IppStatus;
 
 #endif /* IPPSTATUS_H__ */
 
+#define ippStsHashOperationErr           -1019 /* Hash DRBG: an internal error that can occur when hashing */
+#define ippStsMLDSAMaxIterations         -1018 /* The ML-DSA iterations reach maximum. Data weren't generated successfully. */
 #define ippStsInvalidPoint               -1017 /* ippStsInvalidPoint ECC: Invalid point (out of EC).*/
 #define ippStsQuadraticNonResidueErr     -1016 /* SQRT operation on quadratic non-residue value. */
 #define ippStsPointAtInfinity            -1015 /* Point at infinity is detected. */
@@ -632,13 +635,17 @@ typedef enum {
    ippSlidingWindows = 1, IppsSlidingWindows = 1
 } IppsExpMethod;
 
-typedef struct _cpBigNum      IppsBigNumState;
-typedef struct _cpMontgomery  IppsMontState;
-typedef struct _cpPRNG        IppsPRNGState;
-typedef struct _cpPrime       IppsPrimeState;
+typedef struct _cpBigNum          IppsBigNumState;
+typedef struct _cpMontgomery      IppsMontState;
+typedef struct _cpPRNG            IppsPRNGState;
+typedef struct _cpPrime           IppsPrimeState;
+typedef struct _cpHashDRBG        IppsHashDRBGState;
+typedef struct _cpEntropyInputCtx IppsHashDRBG_EntropyInputCtx;
 
 /*  External Bit Supplier */
 typedef IppStatus (IPP_CALL *IppBitSupplier)(Ipp32u* pRand, int nBits, void* pEbsParams);
+/* External entropyInput Supplier */
+typedef IppStatus (IPP_CALL *IppEntropyInputSupplier)(Ipp8u* entropyInput, int* entropyInputBitsLen, const int minEntropyInBits, const int maxBitsLen, const int predictionResistanceRequest);
 
 #define IPP_IS_EQ (0)
 #define IPP_IS_GT (1)
@@ -671,6 +678,8 @@ typedef IppStatus (IPP_CALL *IppBitSupplier)(Ipp32u* pRand, int nBits, void* pEb
 #define MIN_RSA_SIZE (8)
 #define MAX_RSA_SIZE (16*1024)
 
+#define IPPCP_RSA_PKCS1V15_PREHASHED (-1)
+
 typedef struct _cpRSA IppsRSAState;
 
 /* key types */
@@ -898,6 +907,9 @@ IPPAPI( int, ippcpGetEnabledNumThreads, ( void ) )
     #ifndef IPPCP_PREVIEW_ML_KEM
     #define IPPCP_PREVIEW_ML_KEM  (1)
     #endif
+    #ifndef IPPCP_PREVIEW_ML_DSA
+    #define IPPCP_PREVIEW_ML_DSA  (1)
+    #endif
 #endif
 
 /*
@@ -932,10 +944,11 @@ IPPAPI( int, ippcpGetEnabledNumThreads, ( void ) )
 #ifdef IPPCP_PREVIEW_LMS
     /* Parameters set is based on two articles:
      *  RFC8554 (https://www.rfc-editor.org/info/rfc8554)
-     *  https://datatracker.ietf.org/doc/html/draft-fluhrer-lms-more-parm-sets-00
+     *  RFC9858 (https://datatracker.ietf.org/doc/rfc9858)
      */
     typedef enum
     {
+        LMOTS_MIN           = 0,
         LMOTS_SHA256_N32_W1 = 1,
         LMOTS_SHA256_N32_W2 = 2,
         LMOTS_SHA256_N32_W4 = 3,
@@ -943,11 +956,13 @@ IPPAPI( int, ippcpGetEnabledNumThreads, ( void ) )
         LMOTS_SHA256_N24_W1 = 5,
         LMOTS_SHA256_N24_W2 = 6,
         LMOTS_SHA256_N24_W4 = 7,
-        LMOTS_SHA256_N24_W8 = 8
+        LMOTS_SHA256_N24_W8 = 8,
+        LMOTS_MAX           = 9
     } IppsLMOTSAlgo;
 
     typedef enum
     {
+        LMS_MIN            = 4,
         LMS_SHA256_M32_H5  = 5,
         LMS_SHA256_M32_H10 = 6,
         LMS_SHA256_M32_H15 = 7,
@@ -957,7 +972,8 @@ IPPAPI( int, ippcpGetEnabledNumThreads, ( void ) )
         LMS_SHA256_M24_H10 = 11,
         LMS_SHA256_M24_H15 = 12,
         LMS_SHA256_M24_H20 = 13,
-        LMS_SHA256_M24_H25 = 14
+        LMS_SHA256_M24_H25 = 14,
+        LMS_MAX            = 15
     } IppsLMSAlgo;
 
     typedef struct {
@@ -967,6 +983,7 @@ IPPAPI( int, ippcpGetEnabledNumThreads, ( void ) )
 
     typedef struct _cpLMSSignatureState IppsLMSSignatureState;
     typedef struct _cpLMSPublicKeyState IppsLMSPublicKeyState;
+    typedef struct _cpLMSPrivateKeyState IppsLMSPrivateKeyState;
 #endif // IPPCP_PREVIEW_LMS
 
 /*
@@ -992,6 +1009,28 @@ typedef struct {
 typedef struct _cpMLKEMState IppsMLKEMState;
 #endif // IPPCP_PREVIEW_ML_KEM
 
+/*
+// =========================================================
+// ML-DSA
+// =========================================================
+*/
+#ifdef IPPCP_PREVIEW_ML_DSA
+
+typedef enum {
+    ML_DSA_44  = 1,
+    ML_DSA_65  = 2,
+    ML_DSA_87  = 3
+} IppsMLDSAParamSet;
+
+typedef struct {
+   int publicKeySize;
+   int privateKeySize;
+   int signatureSize;
+} IppsMLDSAInfo;
+
+typedef struct _cpMLDSAState IppsMLDSAState;
+#endif // IPPCP_PREVIEW_ML_DSA
+
 #ifdef __cplusplus
 }
 #endif
