@@ -25,24 +25,19 @@
 #ifndef __OWNDEFS_H__
 #define __OWNDEFS_H__
 
-#if defined(_VXWORKS)
-#include <vxWorks.h>
-#undef NONE
-#endif
-
 #ifndef IPPCPDEFS_H__
 #include "ippcpdefs.h"
 #endif
 
-#if !defined(__IPPCP_INLINE)
+#if !defined(IPPCP_INLINE)
 #if defined(__INTEL_COMPILER) || defined(__INTEL_LLVM_COMPILER) || defined(_MSC_VER)
-#define __IPPCP_INLINE static __inline
+#define IPPCP_INLINE static __inline
 #elif defined(__GNUC__)
-#define __IPPCP_INLINE static __inline__
+#define IPPCP_INLINE static __inline__
 #else
-#define __IPPCP_INLINE static
+#define IPPCP_INLINE static
 #endif
-#endif /*__IPPCP_INLINE*/
+#endif /*IPPCP_INLINE*/
 
 /* TODO: to check ICX compiler */
 #if !defined(__NOINLINE)
@@ -55,15 +50,15 @@
 #endif
 #endif /*__NOINLINE*/
 
-#if !defined(__FORCEINLINE)
+#if !defined(IPPCP_FORCEINLINE)
 #if defined(_MSC_VER)
-#define __FORCEINLINE __forceinline
+#define IPPCP_FORCEINLINE __forceinline
 #elif defined(__INTEL_COMPILER) || defined(__INTEL_LLVM_COMPILER) || defined(__GNUC__)
-#define __FORCEINLINE __IPPCP_INLINE __attribute__((always_inline))
+#define IPPCP_FORCEINLINE IPPCP_INLINE __attribute__((always_inline))
 #else
-#define __FORCEINLINE
+#define IPPCP_FORCEINLINE
 #endif
-#endif /*__FORCEINLINE*/
+#endif /*IPPCP_FORCEINLINE*/
 
 #if defined(__INTEL_COMPILER) || defined(__INTEL_LLVM_COMPILER)
 #define __RESTRICT restrict
@@ -83,7 +78,6 @@
 
 /* ia32 */
 #define _IPP_PX 0   /* pure C-code*/
-#define _IPP_M5 1   /* Intel® Quark(TM) processor*/
 #define _IPP_W7 8   /* Intel® Streaming SIMD Extensions 2 (Intel® SSE2)*/
 #define _IPP_T7 16  /* Intel® Streaming SIMD Extensions 3 (Intel® SSE3)*/
 #define _IPP_V8 32  /* Supplemental Streaming SIMD Extensions 3 (SSSE3)*/
@@ -137,12 +131,7 @@
 #endif
 
 /* ia32 */
-#if defined(_M5) /* Intel® Quark(TM) processor */
-#define _IPP         _IPP_M5
-#define _IPP32E      _IPP32E_PX
-#define OWNAPI(name) m5_##name
-
-#elif defined(_W7) /* Intel® SSE2 */
+#if defined(_W7) /* Intel® SSE2 */
 #define _IPP         _IPP_W7
 #define _IPP32E      _IPP32E_PX
 #define OWNAPI(name) w7_##name
@@ -261,8 +250,6 @@
 
 #define _IPP_ARCH_IA32  1
 #define _IPP_ARCH_EM64T 4
-#define _IPP_ARCH_LRB   16
-#define _IPP_ARCH_LRB2  128
 #define _IPP_ARCH_LP64  0
 
 #if defined(_ARCH_IA32)
@@ -282,7 +269,7 @@
 #endif
 
 #if ((_IPP_ARCH == _IPP_ARCH_IA32))
-__IPPCP_INLINE Ipp32s IPP_INT_PTR(const void* ptr)
+IPPCP_INLINE Ipp32s IPP_INT_PTR(const void* ptr)
 {
     union {
         void* Ptr;
@@ -292,7 +279,7 @@ __IPPCP_INLINE Ipp32s IPP_INT_PTR(const void* ptr)
     return dd.Int;
 }
 
-__IPPCP_INLINE Ipp32u IPP_UINT_PTR(const void* ptr)
+IPPCP_INLINE Ipp32u IPP_UINT_PTR(const void* ptr)
 {
     union {
         void* Ptr;
@@ -301,8 +288,8 @@ __IPPCP_INLINE Ipp32u IPP_UINT_PTR(const void* ptr)
     dd.Ptr = (void*)ptr;
     return dd.Int;
 }
-#elif ((_IPP_ARCH == _IPP_ARCH_EM64T) || (_IPP_ARCH == _IPP_ARCH_LRB2))
-__IPPCP_INLINE Ipp64s IPP_INT_PTR(const void* ptr)
+#elif (_IPP_ARCH == _IPP_ARCH_EM64T)
+IPPCP_INLINE Ipp64s IPP_INT_PTR(const void* ptr)
 {
     union {
         void* Ptr;
@@ -312,7 +299,7 @@ __IPPCP_INLINE Ipp64s IPP_INT_PTR(const void* ptr)
     return dd.Int;
 }
 
-__IPPCP_INLINE Ipp64u IPP_UINT_PTR(const void* ptr)
+IPPCP_INLINE Ipp64u IPP_UINT_PTR(const void* ptr)
 {
     union {
         void* Ptr;
@@ -402,8 +389,13 @@ typedef enum {
     idCtxAESXTS,
     idxCtxECES_SM2,
     idCtxGFPECKE,
-    idCtxLMS,
-    idCtxMLKEM
+    idCtxPrivKeyLMS,
+    idCtxPubKeyLMS,
+    idCtxSignLMS,
+    idCtxMLKEM,
+    idCtxMLDSA,
+    idCtxHashDRBGEntrInput,
+    idCtxHashDRBG
 } IppCtxId;
 
 
@@ -643,24 +635,11 @@ extern double __intel_castu64_f64(unsigned __int64 val);
 
 #if defined(_MERGED_BLD)
 #if !defined(_IPP_DYNAMIC)
-/* WIN-32, WIN-64 */
-#if defined(WIN32) || defined(WIN32E)
+/* WIN-32, WIN-64, LIN-32, LIN-64 */
+#if defined(WIN32) || defined(WIN32E) || defined(linux)
 #if (defined(_W7) || defined(_M7))
 #define _IPP_DATA 1
 #endif
-
-#elif defined(linux)
-/* LIN-32, LIN-64 */
-#if (defined(_W7) || defined(_M7))
-#define _IPP_DATA 1
-#endif
-
-
-/* OSX-32, OSX-64 */
-#elif defined(OSX32) || defined(OSXEM64T)
-#if (defined(_Y8))
-#define _IPP_DATA 1
-#endif
 #endif
 #endif
 #else
@@ -668,6 +647,37 @@ extern double __intel_castu64_f64(unsigned __int64 val);
 #define _IPP_DATA 1
 #endif
 
+/* macro for switch constructions */
+#if !defined(IPPCP_FALLTHROUGH)
+#if !defined(_WIN32) && !defined(_WIN64)
+
+#if __STDC_VERSION__ >= 202311L // C23
+#define IPPCP_FALLTHROUGH [[fallthrough]]
+#else
+#define IPPCP_FALLTHROUGH __attribute__((fallthrough))
+#endif
+
+#else
+
+#define IPPCP_FALLTHROUGH \
+    do {                  \
+    } while (0)
+#endif
+
+#endif
+
+#if defined(_MSC_VER) && !defined(__INTEL_COMPILER) && !defined(__INTEL_LLVM_COMPILER)
+#include <intrin.h>
+#define CP_PREVENT_REORDER() _ReadWriteBarrier()
+#else
+#if ((_IPP >= _IPP_W7) || (_IPP32E == _IPP32E_M7))
+#include <emmintrin.h>
+#define CP_PREVENT_REORDER() _mm_mfence()
+#else
+#define CP_PREVENT_REORDER() __asm__ __volatile__("" ::: "memory")
+#endif
+#endif
+
 
 #if defined(__cplusplus)
 }
