@@ -262,16 +262,6 @@ static int cpGetFeatures(Ipp64u* pFeaturesMask)
             /* test if Intel® AVX-512 is supported by OS */
             if (cp_is_avx512_extension())
                 mask |= ippAVX512_ENABLEDBYOS;
-
-#if defined(OSXEM64T)
-            else {
-                /* submit some avx512f instructions, returns 0 */
-                mask |= cp_issue_avx512_instruction();
-                /* and check OS support again */
-                if (cp_is_avx512_extension())
-                    mask |= ippAVX512_ENABLEDBYOS;
-            }
-#endif
         }
     }
     mask = (flgFMA && flgINT && flgGPR) ? (mask | ippCPUID_AVX2)
@@ -394,7 +384,7 @@ IppStatus owncpFeaturesToIdx(Ipp64u* cpuFeatures, int* index)
                     if (ippCPUID_SSE == (*cpuFeatures & ippCPUID_SSE)) {
                         mask   = SSE_MSK;
                         *index = LIB_SSE;
-#if (defined(WIN32E) || defined(LINUX32E) || defined(OSXEM64T)) && !(defined(_ARCH_LRB2))
+#if defined(WIN32E) || defined(LINUX32E)
                         ownStatus =
                             ippStsNotSupportedCpu; /* the lowest CPU supported by Intel Cryptography Primitives Library must at least support Intel® SSE2 for x64 */
 #endif
@@ -488,6 +478,8 @@ static struct {
 /* -9702 */ {MSG_NO_SHARED, "No shared libraries were found in the Waterfall procedure"},
 /* -9701 */ {MSG_NO_DLL, "No DLLs were found in the Waterfall procedure"},
 /* -9700 */ {MSG_LOAD_DLL_ERR, "Error at loading of %s library"},
+/* -1019 */ {ippStsHashOperationErr, "Hash DRBG: an internal error occurred when hashing"},
+/* -1018 */ {ippStsMLDSAMaxIterations, "ippStsMLDSAMaxIterations: The ML-DSA iterations reach maximum. Data weren't generated successfully"},
 /* -1017 */ {ippStsInvalidPoint, "ippStsInvalidPoint ECC: Invalid point (out of EC)"},
 /* -1016 */ {ippStsQuadraticNonResidueErr, "ippStsQuadraticNonResidueErr: SQRT operation on quadratic non-residue value"},
 /* -1015 */ {ippStsPointAtInfinity, "ippStsPointAtInfinity: Point at infinity is detected"},
