@@ -191,14 +191,14 @@ IPP_OWN_DEFN(void, ifma_amm52_dual_p256, (m512* r1,
 }
 
 /* R = (A*B) with norm */
-__IPPCP_INLINE m512 ifma_amm52_p256_norm(const m512 a, const m512 b)
+IPPCP_INLINE m512 ifma_amm52_p256_norm(const m512 a, const m512 b)
 {
     m512 r = ifma_amm52_p256(a, b);
     return ifma_lnorm52(r);
 }
 
 /* R = (A*A) with norm */
-__IPPCP_INLINE m512 ifma_ams52_p256_norm(const m512 a) { return ifma_amm52_p256_norm(a, a); }
+IPPCP_INLINE m512 ifma_ams52_p256_norm(const m512 a) { return ifma_amm52_p256_norm(a, a); }
 
 /* R = (A/2) */
 IPP_OWN_DEFN(m512, ifma_half52_p256, (const m512 a))
@@ -280,7 +280,7 @@ IPP_OWN_DEFN(m512, ifma_frommont52_p256, (const m512 a))
 #define sqr(R, A)    (R) = ifma_ams52_p256_norm((A))
 #define mul(R, A, B) (R) = ifma_amm52_p256_norm((A), (B));
 
-__IPPCP_INLINE m512 ifma_ams52_p256_ntimes(m512 a, Ipp32s n)
+IPPCP_INLINE m512 ifma_ams52_p256_ntimes(m512 a, Ipp32s n)
 {
     for (; n > 0; --n)
         sqr(a, a);
