@@ -40,11 +40,24 @@
 /* BN(1) and reference */
 IPP_OWN_DEFN(IppsBigNumState*, cpBN_OneRef, (void))
 {
+    /* Prevents re-initialization for better multi-threaded/repeated call performance */
+    static volatile int isInitialized = 0;
+
     static IppsBigNumStateChunk cpChunk_BN1 = {
         {idCtxUnknown, ippBigNumPOS, 1, 1, &cpChunk_BN1.value, &cpChunk_BN1.temporary},
         1,
         0
     };
+
+    if (isInitialized) {
+        CP_PREVENT_REORDER();
+        return &cpChunk_BN1.bn;
+    }
+
     BN_SET_ID(&cpChunk_BN1.bn);
+
+    CP_PREVENT_REORDER();
+    isInitialized = 1;
+
     return &cpChunk_BN1.bn;
 }
